#
# spec file for package bazel
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define set_ver_suffix 0

%define shortname bazel-skylib
%define src_install_dir /usr/src/%{shortname}
# set by service set_version:
%define version_unconverted 1.0.3

%if 0%{set_ver_suffix}
%define n_suffix %version_unconverted
%endif

Name:           %{shortname}%{?n_suffix}
Version:        1.0.3
Release:        2.9
Summary:        Set of functions for writing Bazel build rules with Skylark
License:        Apache-2.0
Group:          Development/Tools/Building
URL:            https://github.com/bazelbuild/bazel-skylib
Source:         https://github.com/bazelbuild/bazel-skylib/archive/%{version}.tar.gz#/%{shortname}-%{version}.tar.gz

%description
Skylib is a standard library that provides functions for manipulating
collections, file paths, and common features for writing custom build rules in
Bazel.

%package source
Summary:        Source code of bazel-skylib
Group:          Development/Sources
BuildArch:      noarch
%if 0%{set_ver_suffix}
Provides:       %{shortname}-source = %version
Conflicts:      %{shortname}-source
%endif

%description source
Skylib is a standard library that provides functions for manipulating
collections, file paths, and common features for writing custom build rules in
Bazel.

This package contains source code of Skylib.

%prep
%setup -q -n %{shortname}-%{version}

%build

%install
mkdir -p %{buildroot}%{src_install_dir}
tar -xzf %{SOURCE0} --strip-components=1 -C %{buildroot}%{src_install_dir}

%files source
%license LICENSE
%doc README.md
%{src_install_dir}

%changelog
* Wed Sep  1 2021 Egbert Eich <eich@suse.com>
- Add support for versioned packages. This allows to provide
  multiple versions of this package during the Leap version
  lifecycle.
* Mon Jun  7 2021 Christian Goll <cgoll@suse.com>
- update to 1.0.3
  * copy_file: Add parameter to allow symlinks (#252)
  * Create Gazelle language for Starlark (#251)
  * Create a helper rule (select_file) for selecting a file from outputs of another rule (#233)
  - Significant Changes
  * Move Gazelle extension to //gazelle/bzl and change package name
  * Stop depending on rules_pkg through the federation. (#259)
  - Incompatible Changes
  * Remove links to maprules (#213)
  * Remove old_sets.bzl (#231)
  * It has been deprecated for a while, the code is not really compatible with
    Bazel depset-related changes.
- from 1.0.2
  * Added types.is_set() to test whether an arbitrary object is a set as defined by sets.bzl.
  - Incompatible Changes
  * @bazel_skylib//:lib.bzl is removed. You now must specify specific
    modules via @bazel_skylib//lib:.bzl.
  * maprule.bzl is removed.
  * Added types.is_set() to test whether an arbitrary object is a set as defined by sets.bzl.
- from 1.0.0
  * @bazel_skylib//:lib.bzl is removed. You now must specify specific modules
  * via @bazel_skylib//lib:.bzl.
  * maprule.bzl is removed.
  - New Features
  * Added types.is_set() to test whether an arbitrary object is a set as defined by sets.bzl.
* Mon Aug  5 2019 mrostecki@opensuse.org
- Update to version 0.9.0:
  * fix formatting problem (#169)
  * Give BuildSettingInfo's value field a description (#167)
  * Create new stardoc target for common_settings.bzl (#166)
  * Get docs working again. (#165)
  * Create common build settings (#154)
  * selects.bzl: Add config_setting_group for config_setting AND/OR-chaining (#89)
  * README.md: Fix typo in project name (#161)
  * Add some comments to unittest_test.sh (#159)
  * Make sets.bzl point to new_sets.bzl instead of old_sets.bzl (#158)
  * Fix for --incompatible_no_support_tools_in_action_inputs on Windows (#157)
  * Fix repository for compatibility with --incompatible_no_support_tools_in_action_inputs (#156)
  * run_binary: runs an executable as an action (#153)
  * New rules: native_binary and native_test (#152)
  * copy_file: expose the copying logic (#151)
  * write_file: support different line endings (#150)
  * Minor formatting changes plus doc updates (#147)
  * Fix a number of misc issues to allow google usage of bazel-skylib (#146)
  * Use TEST_SRCDIR for shell tests (#145)
  * Pass through an attribute arguments to `analysistest.make`. (#140)
  * Fix typo (#142)
  * Add licenses() to all BUILD files. (#141)
  * diff_test: add rule and tests (#136)
  * Fix installation instructions (#135)
  * Fix broken link to new_sets doc page (#120)
  * Reformat with buildifier --warnings=all (#138)
  * Regenerate docs + remove maprule.md (#137)
  * Windows: fix tests for native test wrapper (#129)
  * maprule: move functionality to maprule_util.bzl (#132)
  * maprule: hide it, not ready for public use. (#133)
  * Accept kwargs in dicts.add() (#130)
  * maprule: add basic integration test (#131)
  * e2e tests: make them run on Windows (#121)
  * write_file: add rule and tests (#122)
  * copy_file: add rule and tests (#123)
  * Use //... to mean "all packages" (#128)
  * run buildifier 0.22.0 (#125)
  * Fix Buildifier version (#124)
  * maprule: use ctx.resolve_tools (#117)
  * add documentation pages for rules/ and lib/ (#119)
  * CI updates. (#118)
  * fix a number of warnings found by Starlark analyzer (#114)
  * analysistest API for retrieval of actions registered by target under test
  * CI simplification/improvements for buildifier (#113)
  * Add analysis_test rule
  * Add analysis-test test framework (#110)
  * Create CODEOWNERS (#103)
  * Add basic shell testing for unittest.bzl (#108)
  * Add `types.is_depset`. (#105)
  * Add rules to the test_deps target. (#102)
  * Fix example load directive. (#101)
  * Some doc fixes (#100)
  * Add a build_test rule. (#97)
  * Enable tests on Windows (#99)
  * reorder toolchain targets to help clarity (#95)
  * add unittest/toolchains/BUILD as a test dep (#96)
  * add missing license notices (#94)
  * fix various linter errors (#93)
  * Wrap invocation of dict.items() in list(). (#91)
  * maprule: an improved version of genrule() (#86)
  * Buildifier fixes (#87)
  * Run buildifier --lint=fix over the files. (#88)
  * Fix load paths examples in README (#80)
  * unittest.bzl: supports Windows (#84)
  * Fix Skylark analyzer warning. (#81)
  * Add WORKSPACE to the things checked by buildifier. (#79)
  * Fix skylark_library deps for new_sets and unittest. (#76)
* Thu Jan 10 2019 Michał Rostecki <mrostecki@suse.de>
- Initial version 0.6.0
